libxfce4ui-sys-0.2.0+dev has been yanked.
libxfce4ui-sys
This crate provides FFI bindings for libxfce4ui, a UI utility library
for Xfce applications.
In general you will not need to use this crate, and will instead want to use xfce4-ui instead.